<?php

/**
 * Woo Dognet
 *
 * @package   Woo Dognet
 * @author    Vladislav Musílek, Jan Čejka
 * @license   GPL-2.0+
 * @copyright 2014 Vladislav Musílek, 2017 Jan Čejka
 */
class Woo_Dognet_Admin
{

    /**
     * Instance of this class.
     *
     * @since    1.0.0
     *
     * @var      object
     */
    protected static $instance = null;

    /**
     * Slug of the plugin screen.
     *
     * @since    1.0.0
     *
     * @var      string
     */
    protected $plugin_screen_hook_suffix = null;

    /**
     * Initialize the plugin by loading admin scripts & styles and adding a
     * settings page and menu.
     *
     * @since     1.0.0
     */
    private function __construct()
    {

        /*
         * Call $plugin_slug from public plugin class.
         */
        $plugin = Woo_Dognet::get_instance();
        $this->plugin_slug = $plugin->get_plugin_slug();

        add_action('admin_enqueue_scripts', array($this, 'enqueue_admin_styles'));

        // Add the options page and menu item.
        add_action('admin_menu', array($this, 'add_plugin_admin_menu'));

    }

    /**
     * Return an instance of this class.
     *
     * @since     1.0.0
     *
     * @return    object    A single instance of this class.
     */
    public static function get_instance()
    {

        // If the single instance hasn't been set, set it now.
        if (null === self::$instance) {
            self::$instance = new self;
        }

        return self::$instance;
    }

    /**
     * Register and enqueue admin-specific style sheet.
     *
     * @since     1.0.0
     *
     * @return    null    Return early if no settings page is registered.
     */
    public function enqueue_admin_styles()
    {

        if (!isset($this->plugin_screen_hook_suffix)) {
            return;
        }

        $screen = get_current_screen();
        if ($this->plugin_screen_hook_suffix === $screen->id) {
            wp_enqueue_style($this->plugin_slug . '-admin-styles', plugins_url('assets/css/admin.css', __FILE__), array(), Woo_Dognet::VERSION);
        }

        return;
    }

    /**
     * Register the administration menu for this plugin into the WordPress Dashboard menu.
     *
     * @since    1.0.0
     */
    public function add_plugin_admin_menu()
    {

        if (!defined('TORETMENU')) {

            add_menu_page(
                __('Toret plugins', $this->plugin_slug),
                __('Toret plugins', $this->plugin_slug),
                'manage_options',
                'toret-plugins',
                array($this, 'display_toret_plugins_admin_page'),
                plugins_url('assets/images/t-icon.png', __FILE__)
            );

            define('TORETMENU', true);
        }


        add_submenu_page(
            'toret-plugins',
            __('Woo Dognet', $this->plugin_slug),
            __('Woo Dognet', $this->plugin_slug),
            'manage_options',
            'woo-dognet',
            array($this, 'display_plugin_admin_page')
        );

    }

    /**
     * Render the settings page for all plugins
     *
     * @since    1.0.0
     */
    public function display_toret_plugins_admin_page()
    {
        include_once __DIR__ . '/views/toret.php';
    }

    /**
     * Render the settings page for this plugin.
     *
     * @since    1.0.0
     */
    public function display_plugin_admin_page()
    {
        include_once __DIR__ . '/views/admin.php';
    }


}//End class
